@@ -112,13 +112,13 @@ gok_key_lookup_shorter_label (guchar *str)
 		xstr = "Vol\n-";
 	}
 	else if (!strcmp (str, "SunAudioMute")) {
-		xstr = "Mute";
+		xstr = _("Mute");
 	}
 	else if (!strcmp (str, "Pointer\nEnableKeys")) {
-		xstr = "Mouse\nKeys";
+		xstr = _("Mouse\nKeys");
 	}
 	else if (!strcmp (str, "ISO_Left\nTab")) {
-		xstr = "Left\nTab";
+		xstr = _("Left\nTab");
 	}
 	else if (!strcmp (str, "Sterling")) {
 		xstr = "£";
@@ -228,7 +228,70 @@ gok_key_label_from_keysym_string (const guchar *str)
 	if (!str) return g_strdup ("<nil>");
 	strl = strlen(str);
 
-	if (strncmp(str, "KP_", 3) == 0) {
+	if (!strcmp (str, "KP_Divide")) {
+		cp = _("Divide");
+	}
+	else if (!strcmp (str, "KP_Multiply")) {
+		cp = _("Multiply");
+	}
+	else if (!strcmp (str, "KP_Subtract")) {
+		cp = _("Subtract");
+	}
+	else if (!strcmp (str, "KP_Add")) {
+		cp = _("Addition");
+	}
+	else if (!strcmp (str, "KP_Prior") || !strcmp (str, "Prior")) {
+		cp = _("Prior");
+	}
+	else if (!strcmp (str, "KP_Next") || !strcmp (str, "Next")) {
+		cp = _("Next");
+	}
+	else if (!strcmp (str, "KP_Home")) {
+		cp = _("Home");
+	}
+	else if (!strcmp (str, "KP_End")) {
+		cp = _("End");
+	}
+	else if (!strcmp (str, "KP_Up")) {
+		cp = _("Up");
+	}
+	else if (!strcmp (str, "KP_Down")) {
+		cp = _("Down");
+	}
+	else if (!strcmp (str, "KP_Left")) {
+		cp = _("Left");
+	}
+	else if (!strcmp (str, "KP_Right")) {
+		cp = _("Right");
+	}
+	else if (!strcmp (str, "KP_Begin")) {
+		cp = _("Begin");
+	}
+	else if (!strcmp (str, "KP_Decimal")) {
+		cp = _("Decimal");
+	}
+	else if (!strcmp (str, "Meta_L") || !strcmp (str, "Meta_R")) {
+		cp = _("Meta");
+	}
+	else if (!strcmp (str, "Multi_key")) {
+		cp = _("Multi\nkey");
+	}
+	else if (!strcmp (str, "Eisu_toggle")) {
+		cp = _("Eisu\ntoggle");
+	}
+	else if (!strcmp (str, "Henkan_Mode")) {
+		cp = _("Henkan\nMode");
+	}
+	else if (!strcmp (str, "Muhenkan")) {
+		cp = _("Muhenkan");
+	}
+	else if (!strcmp (str, "Mode_switch")) {
+		cp = _("Mode\nswitch");
+	}
+	else if (strncmp(str, "KP_", 3) == 0) {
+ 	        cp = g_strdup (str + 3);
+ 	}
+ 	if (strncmp(str, "KP_", 3) == 0) {
 	        cp = g_strdup (str + 3);
 	}
 	else if ((strl >= 2) && (str[strl-1] == 'L') && (str[strl-2] == '_')) {
@@ -357,7 +420,7 @@ gok_key_label_from_keycode (KeyCode keycode, Display *display, guint level, guin
 {
   char buf[20];
   int extra_rtn, nbytes, state = 0;
-  KeySym keysym;
+  KeySym keysym = 0;
   XkbStateRec xkb_state;
   long ucs;
   gunichar unichar;
@@ -365,10 +428,13 @@ gok_key_label_from_keycode (KeyCode keycode, Display *display, guint level, guin
   keysym = XkbKeycodeToKeysym (display, keycode, group, level);
   if ((ucs = keysym2ucs (keysym)) <= 0) 
   {
+      gint reported_nbytes = XkbTranslateKeySym (display, &keysym, 0, buf, 19, &extra_rtn);
+      gchar *s = NULL;
       /* workaround; XSun gets nbytes wrong, so we truncate to the largest legal value */  
-      nbytes = MIN (XkbTranslateKeySym (display, &keysym, 0, buf, 19, &extra_rtn), 19);
+      nbytes = MIN (reported_nbytes, 19);
       buf[nbytes] = '\0';
-      return gok_key_label_from_keysym_string (XKeysymToString (keysym));
+      if (keysym) s = XKeysymToString (keysym);
+      return gok_key_label_from_keysym_string (s);
   }
   else
   {
