@@ -85,7 +85,8 @@ KEYTYPE_BRANCHLISTITEMS,
 KEYTYPE_BRANCHGUITABLE,
 KEYTYPE_BRANCHGUIVALUATOR,
 KEYTYPE_BRANCHCOMBO,
-KEYTYPE_REPEATNEXT
+KEYTYPE_REPEATNEXT,
+KEYTYPE_ADDWORD
 } GokKeyActionType;
 
 /* display style of key (from the .rc file) */
@@ -121,6 +122,7 @@ KEYSTYLE_DOCK,
 KEYSTYLE_MOUSE,
 KEYSTYLE_MOUSEBUTTON,
 KEYSTYLE_REPEATNEXT,
+KEYSTYLE_ADDWORD,
 KEYSTYLE_INSENSITIVE
 } KeyStyles;
 
