@@ -189,7 +189,7 @@ typedef struct GokAccessMethod {
 } GokAccessMethod;
 
 /* functions */
-gboolean gok_scanner_initialize (const gchar *directory);
+gboolean gok_scanner_initialize (const gchar *directory, const gchar *accessmethod, const gchar *selectaction, const gchar *scanaction);
 void gok_scanner_close (void);
 void gok_scanner_stop (void);
 void gok_scanner_start (void);
